chemcoord.Zmat
==============

.. currentmodule:: chemcoord

.. autoclass:: Zmat

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Zmat.__init__
      ~Zmat.add_data
      ~Zmat.change_numbering
      ~Zmat.copy
      ~Zmat.get_cartesian
      ~Zmat.get_electron_number
      ~Zmat.get_grad_cartesian
      ~Zmat.get_total_mass
      ~Zmat.has_same_sumformula
      ~Zmat.insert
      ~Zmat.iupacify
      ~Zmat.minimize_dihedrals
      ~Zmat.read_zmat
      ~Zmat.sort_index
      ~Zmat.sort_values
      ~Zmat.subs
      ~Zmat.to_latex
      ~Zmat.to_string
      ~Zmat.to_xyz
      ~Zmat.to_zmat
      ~Zmat.write
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Zmat.columns
      ~Zmat.dtypes
      ~Zmat.dummy_manipulation_allowed
      ~Zmat.empty
      ~Zmat.iloc
      ~Zmat.index
      ~Zmat.loc
      ~Zmat.pure_internal_mov
      ~Zmat.safe_iloc
      ~Zmat.safe_loc
      ~Zmat.shape
      ~Zmat.test_operators
      ~Zmat.unsafe_iloc
      ~Zmat.unsafe_loc
   
   